# Supported Similarity Metrics
| # | Name | Input Aliases | Distance |
| --- | --- | --- | --- |
| 1 | l0\_similarity | - | Yes |
| 2 | l1\_similarity | manhattan\_similarity, taxicab\_similarity, city\_block\_similarity, snake\_similarity | Yes |
| 3 | l2\_similarity | euclidean\_similarity | Yes |
| 4 | cosine | driver-kroeber, ochiai | Yes |
| 5 | dice | sorenson, gleason | Yes |
| 6 | dice\_2 | - | - |
| 7 | dice\_3 | - | - |
| 8 | tanimoto | jaccard-tanimoto | Yes |
| 9 | simple\_matching | sokal-michener, rand | Yes |
| 10 | rogers-tanimoto | - | Yes |
| 11 | russel-rao | - | Yes |
| 12 | forbes | - | Yes |
| 13 | simpson | - | - |
| 14 | braun-blanquet | - | Yes |
| 15 | baroni-urbani-buser | - | Yes |
| 16 | kulczynski | - | - |
| 17 | sokal-sneath | sokal-sneath\_1 | Yes |
| 18 | sokal-sneath\_2 | sokal-sneath-2, symmetric\_sokal\_sneath, symmetric-sokal-sneath, | - |
| 19 | sokal-sneath\_3 | sokal-sneath-3 | Yes |
| 20 | sokal-sneath\_4 | sokal-sneath-4 | Yes |
| 21 | jaccard | - | - |
| 22 | faith | - | Yes |
| 23 | michael | - | - |
| 24 | mountford | - | Yes |
| 25 | rogot-goldberg | - | Yes |
| 26 | hawkins-dotson | - | Yes |
| 27 | maxwell-pilliner | - | Yes |
| 28 | harris-lahey | - | - |
| 29 | consonni−todeschini\_1 | consonni−todeschini-1 | Yes |
| 30 | consonni−todeschini\_2 | consonni−todeschini-2 | - |
| 31 | consonni−todeschini\_3 | consonni−todeschini-3 | - |
| 32 | consonni−todeschini\_4 | consonni−todeschini-4 | - |
| 33 | consonni−todeschini\_5 | consonni−todeschini-5 | Yes |
| 34 | austin-colwell | - | Yes |
| 35 | yule\_1 | yule-1 | - |
| 36 | yule\_2 | yule-2 | Yes |
| 37 | holiday-fossum | fossum, holiday\_fossum | Yes |
| 38 | holiday-dennis | dennis, holiday\_dennis | Yes |
| 39 | cole\_1 | cole-1 | - |
| 40 | cole\_2 | cole-2 | - |
| 41 | dispersion | choi | - |
| 42 | goodman-kruskal | goodman\_kruskal | - |
| 43 | pearson-heron | pearson\_heron | Yes |
| 44 | sorgenfrei | - | - |
| 45 | cohen | - | - |
| 46 | peirce\_1 | peirce-1 | - |
| 47 | peirce\_2 | peirce-2 | - |
